from email.policy import default
from nivir.main import Nivir
initTextWelcome = """
------------ NIVIR - GAME ENGINE ---------------
Welcome to NivirGL!
This is a simple game engine made with OpenGL and Glut!
So you can talk with the programmer in Discord:
-   Rinka<3#8908
------------------------
If u wanna learn more about Rinka so you can enter here: https://instabio.cc/rinkadumb
"""
print(initTextWelcome)